OSPFv2
Open Shortest Path First version 2.
URLs Summary
URL | GET | POST | PATCH | PUT | DELETE |
|---|---|---|---|---|---|
/rest/v1/rpc/clear-ip-ospf | N | Y | N | N | N |
/rest/v1/rpc/graceful-restart-prepare-ip-ospf | N | Y | N | N | N |
/rest/v1/running/ospfv2-interfaces/{name}/{address} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2-interfaces/{name}/{address}/authentication/{key-id} | Y | Y | N | N | Y |
/rest/v1/running/ospfv2/{vrf-name} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/areas/{area-id} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/areas/{area-id}/area-ranges/{ip-prefix} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/areas/{area-id}/virtual-link/{neighbor} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/areas/{area-id}/virtual-link/{neighbor}/message-digest-key/{key-id} | Y | Y | N | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/distribute-route/{protocol}/{direction} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/graceful-restart-helper/{address} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/neighbor/{ip} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/network/{prefix} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/saddress/{address} | Y | Y | Y | N | Y |
/rest/v1/running/ospfv2/{vrf-name}/spf | Y | N | Y | N | N |
/rest/v1/rpc/show-ip-ospf-database | N | Y | N | N | N |
/rest/v1/rpc/show-ip-ospf-interface | N | Y | N | N | N |
/rest/v1/rpc/show-ip-ospf-neighbor | N | Y | N | N | N |
/rest/v1/rpc/show-ip-ospf-route | N | Y | N | N | N |
Examples
Clear ip ospf
POST HTTPS://{switch IP}/rest/v1/rpc/clear-ip-ospfGraceful restart prepare ip ospf
POST HTTPS://{switch IP}/rest/v1/rpc/graceful-restart-prepare-ip-ospfShow ip ospf database
POST HTTPS://{switch IP}/rest/v1/rpc/show-ip-ospf-databaseShow ip ospf interface
POST HTTPS://{switch IP}/rest/v1/rpc/show-ip-ospf-interfaceShow ip ospf neighbor
POST HTTPS://{switch IP}/rest/v1/rpc/show-ip-ospf-neighborShow ip ospf route
POST HTTPS://{switch IP}/rest/v1/rpc/show-ip-ospf-routeCreate an ospfv2 interface
POST HTTPS://{switch IP}/rest/v1/running/ospfv2-interfaces
{
"name": "Ethernet1",
"address": "20.1.1.1",
"area-id": "0.0.0.10",
"authentication-type": "TEXT",
"bfd-enable": "true",
"metric": "50",
"dead-interval": "50",
"ttl": "5",
"hello-multiplier": "10",
"hello-interval": "50",
"mtu-ignore": "true",
"network-type": "broadcast",
"priority": "50",
"retransmission-interval": "50",
"transmit-delay": "50",
"passive": "true",
"bfd-profile": "test"
}Create authentication for an OSPFv2 interface
POST HTTPS://{switch IP}/rest/v1/running/ospfv2-interfaces/Ethernet1/20.1.1.1/authentication
{
"key-id": 11,
"md5-key": "1"
}Modify OSPFv2 configurations in a VRF
PATCH HTTPS://{switch IP}/rest/v1/running/ospfv2/Vrf2
{
"as": "true",
"area": "0.0.0.10"
}Create an OSPFv2 area in VRF
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/areas
{
"area-id": "0.0.0.130",
"default-cost": 130,
"stub": "true",
"stub-no-summary": "true",
"nssa-translator-role": "never",
"nssa-no-summary": "true",
"suppress-fa": "false"
}Create an area range in VRF
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/areas/31/area-ranges
{
"ip-prefix": "1.2.7.4/24",
"cost": 70,
"advertise": "true"
}Create an OSPFv2 virtual link
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/areas/21/virtual-link
{
"neighbor": "1.2.3.4",
"enable": "true"
}Create an OSPFv2 message digest key
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/Vrf1/areas/0.0.0.10/virtual-link/1.2.3.4/message-digest-key
{
"key-id": 13,
"md5-key": "123"
}Create an OSPFv2 distribute route
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/distribute-route
{
"protocol": "bgp",
"direction": "OUT",
"access-list": "test_access_list"
}Create an OSPFv2 graceful restart helper
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/graceful-restart-helper
{
"address": "1000",
"enable": "true"
}Create an OSPFv2 neighbor in VRF "default"
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/neighbor
{
"ip": "1.2.3.8",
"enable": "true",
"priority": 30,
"poll-interval": 65536
}Create an OSPFv2 network
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/Vrf1/network
{
"prefix": "1.2.7.4/24",
"area": "70"
}Create an OSPFv2 summary address
POST HTTPS://{switch IP}/rest/v1/running/ospfv2/default/saddress
{
"address": "1.2.8.4/24",
"enable": "true",
"tag": 4294967296,
"no-advertise": "true"
}Modify SPF in VRF
PATCH HTTPS://{switch IP}/rest/v1/running/ospfv2/default/spf
{
"initial-delay": null,
"initial-holdtime": 70,
"maximum-holdtime": 90
}Properties Descriptions
OSPFv2 global
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw enable?
| +--rw router-id?
| +--rw capability-opaque?
| +--rw graceful-restart?
| +--rw grace-period?
| +--rw abr-type?
| +--rw auto-cost-reference-bandwidth?
| +--rw compatible-rfc1583?
| +--rw default-metric?
| +--rw log-adjacency-changes?
| +--rw maximum-paths?
| +--rw proactive-arp?
| +--rw opaque-lsa?
| +--rw rfc1583compatibility?
| +--rw fast-reroute-ti-lfa?
| +--rw fast-reroute-ti-lfa-node-protection?
| +--rw (router-info)?
| | +--:(as)
| | | +--rw as?
| | +--:(area)
| | +--rw area?
| +--rw write-multiplier?
| +--rw passive-interface-default?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
enable | O | "true" "false" | (sub-property of ospfv2) Enable OSPFv2 |
router-id | O | A.B.C.D | (sub-property of ospfv2) Router-id for the OSPF process. |
capability-opaque | O | "true" "false" | (sub-property of ospfv2) Opaque LSA. Default value: "false" |
graceful-restart | O | "true" "false" | (sub-property of ospfv2) Enable OSPF graceful-restart. Default value: "false" |
grace-period | O | 1..1800 | (sub-property of ospfv2) Time to wait before restarting the OSPF session. Default value: 120 |
abr-type | O | "cisco" "shortcut" "standard" | (sub-property of ospfv2) Area border router type. Default value: "cisco" |
auto-cost-reference-bandwidth | O | 1..4294967 | (sub-property of ospfv2) The reference bandwidth in terms of Mbits per second. |
compatible-rfc1583 | O | "true" "false" | (sub-property of ospfv2) Compatible with RFC 1583. |
default-metric | O | 0..16777214 | (sub-property of ospfv2) Metric of redistributed routes. |
log-adjacency-changes | O | "DETAIL" "BRIEF" | (sub-property of ospfv2) Enbale recording adjacency changes log. |
maximum-paths | O | 1..256 | (sub-property of ospfv2) Control the maximum number of equal cost paths Default value: 256 |
proactive-arp | O | "true" "false" | (sub-property of ospfv2) Enables or disables sending ARP requests to update neighbor table entries. Default value: "true" |
opaque-lsa | O | "true" "false" | (sub-property of ospfv2) Enable the Opaque-LSA capability (RFC2370) |
rfc1583compatibility | O | "true" "false" | (sub-property of ospfv2) Enable the RFC 1583 compatibility flag. |
fast-reroute-ti-lfa | O | "true" "false" | (sub-property of ospfv2) Activates TI-LFA for all interfaces. |
fast-reroute-ti-lfa-node-protection | O | "true" "false" | (sub-property of ospfv2) Activates TI-LFA and Protection for node fault |
as | O | "true" "false" | (sub-property of ospfv2) Mutually exclusive with: - area Enable the Router Information functionality with AS flooding scope. |
area | O | "true" "false" | (sub-property of ospfv2) Mutually exclusive with: - as Enable the Router Information functionality with Area flooding scope. |
write-multiplier | O | 1..100 | (sub-property of ospfv2) The amount of work done in the packet read and write threads. Default value: 20 |
passive-interface-default | O | "true" "false" | (sub-property of ospfv2) Make all interfaces that belong to this router passive by default. |
OSPFv2 areas for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw areas
| | +--rw area* [area-id]
| | +--rw area-id
| | +--rw default-cost?
| | +--rw filter-list-in?
| | +--rw filter-list-out?
| | +--rw shortcut?
| | +--rw authentication-type?
| | +--rw authentication-key?
| | +--rw nssa-no-summary?
| | +--rw suppress-fa?
| | +--rw nssa-translator-role?
| | +--rw stub?
| | +--rw stub-no-summary?
| | +--rw virtual-link* [neighbor]
| | | +--rw neighbor
| | | +--rw enable?
| | | +--rw authentication-type?
| | | +--rw authentication-key?
| | | +--rw message-digest-key* [key-id]
| | | | +--rw key-id
| | | | +--rw md5-key?
| | | +--rw dead-interval?
| | | +--rw hello-interval?
| | | +--rw retransmit-interval?
| | | +--rw transmit-delay?
| | +--rw area-ranges
| | +--rw area-range* [ip-prefix]
| | +--rw ip-prefix
| | +--rw cost?
| | +--rw substitute?
| | +--rw advertise?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
areas | M | | (sub-property of ospfv2) Path-only node, has no configurable value. |
area-id | M | A.B.C.D | (sub-property of areas) 32-bit number identifying the OSPF area. |
default-cost | O | 0..16777215 | (sub-property of areas) Advertised default summary cost. |
filter-list-in | O | string | (sub-property of areas) Filter networks getting in OSPF areas. |
filter-list-out | O | string | (sub-property of areas) Filter networks getting out OSPF areas. |
shortcut | O | "default" "disable" "enable" | (sub-property of areas) Configure the area as Shortcut capable. Default value: "default" |
authentication-type | O | "MD5HMAC" "TEXT" "NONE" | (sub-property of areas) Authentication type. |
authentication-key | O | A string that represents a credential, such as a password or a key for OSPF/BGP sessions | (sub-property of areas) Simple text OSPF password. |
nssa-no-summary | O | "true" "false" | (sub-property of areas) Do not inject inter-area routes into nssa. Default value: "false" |
suppress-fa | O | "true" "false" | (sub-property of areas) Suppress Forwarding Address generation. Default value: "false" |
nssa-translator-role | O | "always" "candidate" "never" | (sub-property of areas) Nssa area translator role. |
stub | O | "true" "false" | (sub-property of areas) Config the area as stub area. |
stub-no-summary | O | "true" "false" | (sub-property of areas) Do not inject inter-area routes into stub Default value: "false" |
virtual-link | M | | (sub-property of areas) Path-only node, has no configurable value. Virtual link parameters. |
neighbor | M | A.B.C.D | (sub-property of virtual-link) Router ID of the remote ABR. |
enable | O | "true" "false" | (sub-property of virtual-link) Enable virtual link. |
authentication-type | O | "MD5HMAC" "TEXT" "NONE" | (sub-property of virtual-link) Authentication type. |
authentication-key | O | A string that represents a credential, such as a password or a key for OSPF/BGP sessions | (sub-property of virtual-link) Simple text OSPF password. |
message-digest-key | M | | (sub-property of virtual-link) Path-only node, has no configurable value. |
key-id | M | 0..255 | (sub-property of message-digest-key) Key id |
md5-key | O | A string that represents a credential, such as a password or a key for OSPF/BGP sessions | (sub-property of message-digest-key) The OSPF password. |
dead-interval | O | 1..65535 | (sub-property of virtual-link) Interval time after which a neighbor is declared down. |
hello-interval | O | 1..65535 | (sub-property of virtual-link) Time between HELLO packets. |
retransmit-interval | O | 1..65535 | (sub-property of virtual-link) Time between retransmitting lost link state advertisements. |
transmit-delay | O | 1..65535 | (sub-property of virtual-link) Link state transmit delay. |
area-ranges | M | | (sub-property of areas) Path-only node, has no configurable value. |
ip-prefix | M | A.B.C.D/M | (sub-property of area-ranges) Designated IP range. |
cost | O | 0..16777215 | (sub-property of area-ranges) Set an explicit metric. |
substitute | O | A.B.C.D/M | (sub-property of area-ranges) Substitute summarized prefix with another prefix. |
advertise | O | "true" "false" | (sub-property of area-ranges) Summarize intra area paths from specified area into one Type-3 summary-LSA. |
OSPFv2 distance for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw all?
| +--rw inter-area?
| +--rw intra-area?
| +--rw external?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
all | O | 0..255 | (sub-property of ospfv2) Preference for intra-area, inter-area, and external routes. |
inter-area | O | 0..255 | (sub-property of ospfv2) Preference for inter-area routes. |
intra-area | O | 0..255 | (sub-property of ospfv2) Preference for intra-area routes. |
external | O | 0..255 | (sub-property of ospfv2) Preference for AS external and NSSA routes. |
OSPFv2 saddress for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw saddress* [address]
| | +--rw address
| | +--rw enable?
| | +--rw tag?
| | +--rw no-advertise?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
saddress | M | | (sub-property of ospfv2) Path-only node, has no configurable value. |
address | M | A.B.C.D/M | (sub-property of saddress) IP address to distribute summary. |
enable | O | "true" "false" | (sub-property of saddress) Enable summary address. |
tag | O | 1..4294967295 | (sub-property of saddress) Tag for summary route |
no-advertise | O | "true" "false" | (sub-property of saddress) Don't advertise the summary address to others |
OSPFv2 graceful restart helper for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw graceful-restart-helper* [address]
| | +--rw address
| | +--rw enable?
| +--rw graceful-restart-helper-enable?
| +--rw strict-lsa-checking?
| +--rw planned-only?
| +--rw supported-grace-time-interval?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
graceful-restart-helper | M | | (sub-property of ospfv2) Path-only node, has no configurable value. |
address | M | A.B.C.D | (sub-property of graceful-restart-helper) IP address to enable graceful-restart helper |
enable | O | "true" "false" | (sub-property of graceful-restart-helper) Enable graceful-restart helper |
graceful-restart-helper-enable | O | "true" "false" | (sub-property of ospfv2) Enable graceful-restart helper |
strict-lsa-checking | O | "true" "false" | (sub-property of ospfv2) Enabel strict LSA checking. |
planned-only | O | "true" "false" | (sub-property of ospfv2) Only implement planned restart. |
supported-grace-time-interval | O | 10..1800 | (sub-property of ospfv2) Supported grace time as graceful-restart helper. |
OSPFv2 max metric for VRF
Advertise own Router-LSA with infinite distance (stub router). Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw administrative?
| +--rw on-shutdown?
| +--rw on-startup?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
administrative | O | "true" "false" | (sub-property of ospfv2) Administratively applied, for an indefinite period. |
on-shutdown | O | 5..100 | (sub-property of ospfv2) Advertise stub-router prior to full shutdown of OSPF. |
on-startup | O | 5..86400 | (sub-property of ospfv2) Automatically advertise stub Router-LSA on startup of OSPF. |
OSPFv2 neighbor for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw neighbor* [ip]
| | +--rw ip
| | +--rw enable?
| | +--rw priority?
| | +--rw poll-interval?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
neighbor | M | | (sub-property of ospfv2) Path-only node, has no configurable value. Neighbor list. |
ip | M | A.B.C.D | (sub-property of neighbor) Neighbor IP address. |
enable | O | "true" "false" | (sub-property of neighbor) Configures OSPF neighbors for NBMA and point-to-multipoint non-broadcast networks. |
priority | O | 0..255 | (sub-property of neighbor) Neighbor Priority. |
poll-interval | O | 1..65535 | (sub-property of neighbor) Dead Neighbor Polling interval. |
OSPFv2 networks for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw network* [prefix]
| | +--rw prefix
| | +--rw area?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
network | M | | (sub-property of ospfv2) Path-only node, has no configurable value. Enable routing on list of IP network. |
prefix | M | A.B.C.D/M | (sub-property of network) Prefix on which routing needs to be enabled. |
area | O | A.B.C.D | (sub-property of network) Area ID for this network. |
OSPFv2 distribute route for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw distribute-route* [protocol direction]
| | +--rw protocol
| | +--rw direction
| | +--rw route-map?
| | +--rw access-list?
| | +--rw always?
| | +--rw metric?
| | +--rw metric-type?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
distribute-route | M | | (sub-property of ospfv2) Path-only node, has no configurable value. |
protocol | M | "kernel" "connected" "local" "static" "rip" "ospf" "isis" "bgp" "eigrp" "nhrp" "table" "vnc" "vnc-direct" "babel" "sharp" "openfabric" "default-route" | (sub-property of distribute-route) Protocol to import. |
direction | M | "IMPORT" "EXPORT" | (sub-property of distribute-route) Export or import router. |
route-map | O | string | (sub-property of distribute-route) Route map reference. |
access-list | O | string | (sub-property of distribute-route) Access-list filter name. |
always | O | "true" "false" | (sub-property of distribute-route) Always advertise default route. |
metric | O | 0..16777214 | (sub-property of distribute-route) OSPF default metric. |
metric-type | O | "TYPE_1" "TYPE_2" | (sub-property of distribute-route) Metric type (1/2). |
OSPFv2 timer for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw distribute-route* [protocol direction]
| | +--rw protocol
| | +--rw direction
| | +--rw route-map?
| | +--rw access-list?
| | +--rw always?
| | +--rw metric?
| | +--rw metric-type?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
refresh-interval | O | 10..1800 | (sub-property of ospfv2) The maximum time between distinct originations of any particular LSA, value in units seconds. Default value: 1800 |
lsa-min-arrival | O | 0..600000 | (sub-property of ospfv2) Minimum delay in receiving new version of an LSA. Default value: 1000 |
lsa-all | O | 0..5000 | (sub-property of ospfv2) LSA delay between transmissions. Default value: 5000 |
spf | M | | (sub-property of ospfv2) Path-only node, has no configurable value. |
initial-delay | M | 0..600000 | (sub-property of spf) Specifies the minimum amount of time to delay SPF calculation. |
initial-holdtime | M | 0..600000 | (sub-property of spf) Separated consecutive SPF calculations. |
maximum-holdtime | M | 0..600000 | (sub-property of spf) Maximum of holdtime. |
aggregation-timer | O | 5..1800 | (sub-property of ospfv2) Summarisation starts only after this delay timer expiry. Default value: 5 |
OSPFv2 PCE for VRF
Tree Diagrams
+--rw ospfv2
| +--rw ospfv2-instance* [vrf-name]
| +--rw vrf-name
| +--rw address?
| +--rw flag?
| +--rw domain-as?
| +--rw neighbor-as?
| +--rw pce-scope?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2 | M | | Path-only node, has no configurable value. Top-level configuration for the OSPFv2 router. |
vrf-name | M | "default" vrf name | (sub-property of ospfv2) Name of VRF instance. |
address | O | A.B.C.D | (sub-property of ospfv2) The PCE IP address. |
flag | O | 0..4294967295 | (sub-property of ospfv2) Flag. |
domain-as | O | 0..65535 | (sub-property of ospfv2) Autonomous System (AS) numbers of controlled domains. |
neighbor-as | O | 0..65535 | (sub-property of ospfv2) neighbor ASs. |
pce-scope | O | 0..4294967295 | (sub-property of ospfv2) Pce scope. |
OSPFv2 interfaces
Tree Diagrams
+--rw ospfv2-interfaces
+--rw ospfv2-interface* [name address]
+--rw name
+--rw address
+--rw vrf-name?
+--rw area-id?
+--rw authentication-type?
+--rw authentication-key?
+--rw bfd-enable?
+--rw metric?
+--rw dead-interval?
+--rw ttl?
+--rw hello-multiplier?
+--rw hello-interval?
+--rw mtu-ignore?
+--rw network-type?
+--rw priority?
+--rw retransmission-interval?
+--rw transmit-delay?
+--rw passive?
+--rw bfd-profile?
+--rw authentication* [key-id]
+--rw key-id
+--rw md5-key?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
ospfv2-interfaces | M | | Path-only node, has no configurable value. |
name | M | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of ospfv2-interfaces) Name of interface. |
address | M | A.B.C.D | (sub-property of ospfv2-interfaces) Restricted to just the IP address.You can set this value to 0.0.0.0 to enable OSPF for all addresses configured on this interface. |
vrf-name | O | "default" vrf name | (sub-property of ospfv2-interfaces) Name of VRF. |
area-id | O | A.B.C.D | (sub-property of ospfv2-interfaces) Area ID for this network. |
authentication-type | O | "MD5HMAC" "TEXT" "NONE" | (sub-property of ospfv2-interfaces) Authentication type. |
authentication-key | O | A string that represents a credential, such as a password or a key for OSPF/BGP sessions | (sub-property of ospfv2-interfaces) Simple text OSPF password. |
bfd-enable | O | "true" "false" | (sub-property of ospfv2-interfaces) Enable bfd. |
metric | O | 1..65535 | (sub-property of ospfv2-interfaces) Cost value set to router-LSA's metric field |
dead-interval | O | 1..65535 | (sub-property of ospfv2-interfaces) Interval time after which a neighbor is declared down. |
ttl | O | 1..255 | (sub-property of ospfv2-interfaces) Time to live. |
hello-multiplier | O | 1..10 | (sub-property of ospfv2-interfaces) Set number of seconds for RouterDeadInterval timer value. |
hello-interval | O | 1..65535 | (sub-property of ospfv2-interfaces) Set number of seconds for HelloInterval timer value. |
mtu-ignore | O | "true" "false" | (sub-property of ospfv2-interfaces) Enable mtu ignore. |
network-type | O | "broadcast" "non-broadcast" "point-to-multipoint" "point-to-point" | (sub-property of ospfv2-interfaces) Set network type. |
priority | O | 0..255 | (sub-property of ospfv2-interfaces) Set RouterPriority integer value. |
retransmission-interval | O | 1..65535 | (sub-property of ospfv2-interfaces) Set number of seconds for RxmtInterval timer value. |
transmit-delay | O | 1..65535 | (sub-property of ospfv2-interfaces) Set number of seconds for InfTransDelay value. |
passive | O | "true" "false" | (sub-property of ospfv2-interfaces) Do not speak OSPF on the interface. |
bfd-profile | O | string | (sub-property of ospfv2-interfaces) Specify a BFD profile. |
authentication | M | | (sub-property of ospfv2-interfaces) Path-only node, has no configurable value. |
key-id | M | 0..255 | (sub-property of authentication) Key id |
md5-key | O | A string that represents a credential, such as a password or a key for OSPF/BGP sessions | (sub-property of authentication) The MD5 password. |
Show ip ospf neighbor
Tree Diagrams
+---x show-ip-ospf-neighbor
| +---w input
| | +---w vrf?
| | +---w (options)?
| | +--:(all)
| | | +---w all?
| | +--:(detail)
| | | +---w detail?
| | +--:(neighbor-id)
| | | +---w neighbor-id?
| | +--:(interface)
| | +---w interface?
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-ip-ospf-neighbor | M | | Path-only node, has no configurable value. Show ip ospf neighbor information. |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. |
all | O | empty | (sub-property of input) Mutually exclusive with: - detail - neighbor-id - interface Display all neighbors information. |
detail | O | empty | (sub-property of input) Mutually exclusive with: - all - neighbor-id - interface Display more details. |
neighbor-id | O | A.B.C.D | (sub-property of input) Mutually exclusive with: - all - detail - interface Display information of specific neighbor-id. |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Mutually exclusive with: - all - detail - neighbor-id Display information of specific interface. |
data | RO | <anydata> | (sub-property of output) |
Show ip ospf route
Tree Diagrams
+---x show-ip-ospf-route
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-ip-ospf-route | M | | Path-only node, has no configurable value. Show ip ospf route information. |
data | RO | <anydata> | (sub-property of output) |
Show ip ospf database
Tree Diagrams
+---x show-ip-ospf-database
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-ip-ospf-database | M | | Path-only node, has no configurable value. Show ip ospf database information. |
data | RO | <anydata> | (sub-property of output) |
Show ip ospf interface
Tree Diagrams
+---x show-ip-ospf-interface
| +---w input
| | +---w (options)?
| | +--:(traffic)
| | | +---w traffic?
| | +--:(interface)
| | +---w interface?
| +--ro output
| +--ro data?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
show-ip-ospf-interface | M | | Path-only node, has no configurable value. Show ip ospf interface information. |
traffic | O | empty | (sub-property of input) Mutually exclusive with: - interface Display interface counter information. |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Mutually exclusive with: - traffic Display information of specific interface. |
data | RO | <anydata> | (sub-property of output) |
Clear ip ospf
Tree Diagrams
+---x clear-ip-ospf
| +---w input
| +---w vrf?
| +---w interface?
| +---w neighbor?
| +---w process?Table of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
clear-ip-ospf | M | | Path-only node, has no configurable value. Clear ospf data structures. |
vrf | O | "default" vrf name | (sub-property of input) Name of VRF instance. |
interface | O | Ethernet name Lag1..9999 Vlan1..4094 Ethernet sub-interface name Link-aggregation sub-interface name | (sub-property of input) Clear information of specific interface. |
neighbor | O | A.B.C.D | (sub-property of input) Display information of specific neighbor-id. |
process | O | empty | (sub-property of input) Reset OSPF Process |
Graceful restart prepare ip ospf
Tree Diagrams
+---x graceful-restart-prepare-ip-ospfTable of Properties
Name | Required | Type/Range | Description |
|---|---|---|---|
graceful-restart-prepare-ip-ospf | M | | Path-only node, has no configurable value. Initiate a graceful restart for all OSPF instances. |